@@ -3,7 +3,7 @@ package CohortExplorer::Command::Query::Search;
 use strict;
 use warnings;
 
-our $VERSION = 0.01;
+our $VERSION = 0.05;
 
 use base qw(CohortExplorer::Command::Query);
 use CLI::Framework::Exceptions qw( :all );
@@ -14,14 +14,14 @@ sub usage_text {    # Command is available to both standard and longitudinal dat
 
 	q\
               search [--out|o=<directory>] [--export|e=<table>] [--export-all|a] [--save-command|s] [--stats|S] [--cond|c=<cond>] 
-              [variable] : search entities with/without condition(s) on variable(s)
+              [variable] : search entities with/without conditions on variables
               
               
               NOTES
-                 The variables Entity_ID and Visit (if applicable) must not be provided as args as they are already part of the 
-                 query-set however, both can be used to impose conditions.
+                 The variables Entity_ID and Visit (if applicable) must not be provided as arguments as they are already part of
+                 the query-set however, both can be used to impose conditions.
 
-                 Other variables in args/cond (option) must be referenced as 'Table.Variable'.
+                 Other variables in arguments/cond (option) must be referenced as 'Table.Variable'.
 
                  The conditions can be imposed using the operators: =, !=, >=, >, <, <=, between, not_between, like, not_like, in, 
                  not_in and regexp.
@@ -30,16 +30,15 @@ sub usage_text {    # Command is available to both standard and longitudinal dat
 
 
               EXAMPLES
-                 search --out=/home/user/exports --cond=DS.Status="{'=','CTL'}" --stats --save-search --cond=CER.Score="{'<=','30'}"
-                          SC.Date FH.Ethnicity
+                 search --out /home/user/exports --stats --save-command --cond CER.Score="{'<=','30'}" SC.Date
 
-                 search --out=/home/user/exports --export-all --cond=SD.Subject_Sex="{'=','Male'}" CER.Score DIS.Status
+                 search --out /home/user/exports --export-all --cond SD.Subject_Sex="{'=','Male'}" CER.Score DIS.Status
 
-                 search -o'/home/user/exports' -e DS -e SD -c Entity_ID="{'like',['SUB100%','SUB200%']}" DIS.Status
+                 search -o /home/user/exports -e DS -e SD -c Entity_ID="{'like',['SUB100%','SUB200%']}" DIS.Status
 
-                 search -o'/home/user/exports' -Ssa -c Visit="{'in',['1','3','5']}" DIS.Status 
+                 search -o /home/user/exports -Ssa -c Visit="{'in',['1','3','5']}" DIS.Status 
 
-                 search -o'/home/user/exports' -c CER.Score="{'between',['25','30']}" DIS.Status
+                 search -o /home/user/exports -c CER.Score="{'between',['25','30']}" DIS.Status
  \;
 }
 
@@ -51,8 +50,7 @@ sub get_query_parameters {
 	my @static_tables   = @{ $datasource->static_tables() || [] };
 	my $struct          = $datasource->entity_structure();
 	my %param;
-	my @vars_in_condition =
-	  grep ( !/^(Entity_ID|Visit)$/, keys %{ $opts->{cond} } );
+	my @vars_in_condition = grep ( !/^(Entity_ID|Visit)$/, keys %{ $opts->{cond} } );
 	
 	my %args = map { $_ => 1 } @args;
 	my @vars = ( @args, grep { !$args{$_} } @vars_in_condition );
@@ -68,12 +66,9 @@ sub get_query_parameters {
                 # Each key contains its own SQL parameters
                 # In static tables the rows are grouped on Entity_ID where as in dynamic tables
                 # (i.e. longitudinal datasources) the rows are grouped on Entity_ID and Visit
-                push
-		  @{ $param{$table_type}{-where}{ $struct->{-columns}{table} }{-in} },
-		  $1;
-
-		push @{ $param{$table_type}{-where}{ $struct->{-columns}{variable} }
-			  {-in} }, $2;
+                push @{ $param{$table_type}{-where}{ $struct->{-columns}{table} }{-in} }, $1;
+                
+                push @{ $param{$table_type}{-where}{ $struct->{-columns}{variable} }{-in} }, $2;
 		push @{ $param{$table_type}{-columns} },
 		    " CAST( GROUP_CONCAT( "
 		  . ( $table_type eq 'static' ? 'DISTINCT' : '' )
@@ -139,7 +134,8 @@ sub process_result_set {
 	my %result_entity;
 
 	# Write result set
-	my $fh = FileHandle->new("> $dir/QueryOutput.csv")
+        my $file = File::Spec->catfile($dir, "QueryOutput.csv");
+	my $fh = FileHandle->new("> $file")
 	  or throw_cmd_run_exception( error => "Failed to open file: $!" );
 
 	# Returns hash ref to hash with key as entity_id and value either:
@@ -193,7 +189,7 @@ sub process_table {
 	}
 
 	# Add Visit column to the header if the table is dynamic
-	my $file      = "$dir/$table.csv";
+	my $file = File::Spec->catfile($dir, "$table.csv");
 	my $untainted = $1 if ( $file =~ /^(.+)$/ );
 	my $fh        = FileHandle->new("> $untainted")
 	  or throw_cmd_run_exception( error => "Failed to open file: $!" );
@@ -264,7 +260,7 @@ __END__
 
 =head1 NAME
 
-CohortExplorer::Command::Query::Search - CohortExplorer class to search entities with or without condition(s) on variable(s)
+CohortExplorer::Command::Query::Search - CohortExplorer class to search entities
 
 =head1 SYNOPSIS
 
@@ -334,15 +330,15 @@ The variables C<Entity_ID> and C<Visit> (if applicable) must not be provided as
 
 =head1 EXAMPLES
 
- search --out=/home/user/exports --cond=DS.Status="{'=','CTL'}" --stats --save-search --cond=CER.Score="{'<=','30'}" SC.Date FH.Ethnicity
+ search --out /home/user/exports --stats --save-command --cond DS.Status="{'=','CTL'}" SC.Date
 
- search --out=/home/user/exports --export-all --cond=SD.Subject_Sex="{'=','Male'}" CER.Score DIS.Status
+ search --out /home/user/exports --export-all --cond SD.Subject_Sex="{'=','Male'}" CER.Score DIS.Status
 
- search -o'/home/user/exports' -e DS -e SD -c Entity_ID="{'like',['SUB100%','SUB200%']}" DIS.Status
+ search -o /home/user/exports -e DS -e SD -c Entity_ID="{'like',['SUB100%','SUB200%']}" DIS.Status
 
- search -o'/home/user/exports' -Ssa -c Visit="{'in',['1','3','5']}" DIS.Status 
+ search -o /home/user/exports -Ssa -c Visit="{'in',['1','3','5']}" DIS.Status 
 
- search -o'/home/user/exports' -c CER.Score="{'between',['25','30']}" DIS.Status
+ search -o /home/user/exports -c CER.Score="{'between',['25','30']}" DIS.Status
 
 =head1 DIAGNOSTICS
 
