@@ -7,7 +7,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 use CohortExplorer::Application;
 
@@ -197,7 +197,7 @@ Currently the application does not support the querying of datasources with mult
 
 =head1 DEPENDENCIES
 
-Carp
+L<Carp>
 
 L<CLI::Framework>
 
